:orphan:

.. _api_documentation:

=================
API Reference
=================

IRASA
-----
:py:mod:`pyrasa.irasa`

.. automodule:: pyrasa.irasa
   :no-members:
   :no-inherited-members:

.. currentmodule:: pyrasa.irasa

.. autosummary::
   :toctree: _autoexamples/

   irasa
   irasa_sprint

IRASA MNE
---------
:py:mod:`pyrasa.irasa_mne`

.. automodule:: pyrasa.irasa_mne
   :no-members:
   :no-inherited-members:

.. currentmodule:: pyrasa.irasa_mne

.. autosummary::
   :toctree: _autoexamples/

   irasa_raw
   irasa_epochs


Aperiodic Utilities
-------------------
:py:mod:`pyrasa.utils.aperiodic_utils`

.. automodule:: pyrasa.utils.aperiodic_utils
   :no-members:
   :no-inherited-members:

.. currentmodule:: pyrasa.utils.aperiodic_utils

.. autosummary::
   :toctree: _autoexamples/

   compute_aperiodic_model
   compute_aperiodic_model_sprint


Aperiodic Model Fitting
-----------------------
:py:mod:`pyrasa.utils.fit_funcs`

.. automodule:: pyrasa.utils.fit_funcs
   :no-members:
   :no-inherited-members:

.. currentmodule:: pyrasa.utils.fit_funcs

.. autosummary::
   :toctree: _autoexamples/

   AbstractFitFun
   FixedFitFun
   KneeFitFun

   
Periodic Feature Extraction
---------------------------
:py:mod:`pyrasa.utils.peak_utils`

.. automodule:: pyrasa.utils.peak_utils
   :no-members:
   :no-inherited-members:

.. currentmodule:: pyrasa.utils.peak_utils

.. autosummary::
   :toctree: _autoexamples/

   get_peak_params
   get_peak_params_sprint
   get_band_info